import { useEffect, useState } from 'react'
import { EventsOn } from '../../wailsjs/runtime/runtime'
import { StartDownload } from '../../wailsjs/go/main/App'
import { Close } from '../../wailsjs/go/service/SQLiteHelper'
import {
  Dialog,
  DialogContent,
  DialogDescription,
  DialogFooter,
  DialogHeader,
  DialogTitle,
} from '@/components/ui/dialog'
import { Button } from '@/components/ui/button'
import { Progress } from '@/components/ui/progress'

const Download = (props: { onFinish: () => void }) => {
  const [isOpen, setIsOpen] = useState(true)

  const [downloadProgress, setDownloadProgress] = useState<number>(0.0)
  const [isDisabled, setIsDisabled] = useState(true)

  const [title, setTitle] = useState('Downloading')

  useEffect(() => {
    Close().then(res => {
      StartDownload().then(res => {
        console.log(res)
      })
      EventsOn('download-progress', (progress: number) => {
        setDownloadProgress(progress)
        if (progress === 100) {
          props.onFinish()
          setTitle('Completed')
          setIsDisabled(false)
        }
      })
    })
  }, [])

  return (
    <Dialog open={isOpen}>
      <DialogContent>
        <DialogHeader>
          <DialogTitle>{title}</DialogTitle>
        </DialogHeader>
        <Progress value={downloadProgress} />
        <DialogFooter>
          <Button
            onClick={() => {
              setIsOpen(false)
            }}
            disabled={isDisabled}
          >
            Close
          </Button>
        </DialogFooter>
      </DialogContent>
    </Dialog>
  )
}

export default Download
